==> libpng-1.0.50-i486-1sys.tgz: install/doinst.sh <==
#
( cd usr/lib ; rm -rf libpng.a )
( cd usr/lib ; ln -sf libpng10.a libpng.a )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so libpng12.so.0 )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.18 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.18 )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.40 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.40 )
( cd usr/lib ; rm -rf libpng10.so.0 )
( cd usr/lib ; ln -sf libpng10.so.0.1.0.50 libpng10.so.0 )
( cd usr/lib ; rm -rf libpng10.so )
( cd usr/lib ; ln -sf libpng10.so.0 libpng10.so )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.25 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.25 )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.2 libpng.so.3 )
( cd usr/lib ; rm -rf libpng.so )
( cd usr/lib ; ln -sf libpng.so.2 libpng.so )
( cd usr/lib ; rm -rf libpng.so.1 )
( cd usr/lib ; ln -sf libpng.so.2 libpng.so.1 )
( cd usr/lib/pkgconfig ; rm -rf libpng.pc )
( cd usr/lib/pkgconfig ; ln -sf libpng10.pc libpng.pc )
( cd usr/lib ; rm -rf libpng12.so )
( cd usr/lib ; ln -sf libpng10.so libpng12.so )
( cd usr/lib ; rm -rf libpng.so.3.1.2.38 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.38 )
( cd usr/lib ; rm -rf libpng.so.2 )
( cd usr/lib ; ln -sf libpng.so.2.1.0.50 libpng.so.2 )
( cd usr/lib ; rm -rf libpng.so.3.1.2.40 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.40 )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.38 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.38 )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.35 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.35 )
( cd usr/lib ; rm -rf libpng.so.3.1.2.35 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.35 )
( cd usr/lib ; rm -rf libpng.so.0 )
( cd usr/lib ; ln -sf libpng.so.2 libpng.so.0 )
( cd usr/lib ; rm -rf libpng.so.3.1.2.18 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.18 )
( cd usr/lib ; rm -rf libpng.so.3.1.2.25 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.25 )
( cd usr/lib ; rm -rf libpng12.a )
( cd usr/lib ; ln -sf libpng10.a libpng12.a )
( cd usr/include ; rm -rf libpng )
( cd usr/include ; ln -sf libpng10 libpng )
( cd usr/include ; rm -rf png.h )
( cd usr/include ; ln -sf libpng10/png.h png.h )
( cd usr/include ; rm -rf libpng12 )
( cd usr/include ; ln -sf libpng10 libpng12 )
( cd usr/include ; rm -rf pngconf.h )
( cd usr/include ; ln -sf libpng10/pngconf.h pngconf.h )
( cd usr/bin ; rm -rf libpng-config )
( cd usr/bin ; ln -sf libpng10-config libpng-config )

==> libpng-1.0.54-i486-1sys.tgz: install/doinst.sh <==
#
( cd usr/include ; rm -rf libpng12 )
( cd usr/include ; ln -sf libpng10 libpng12 )
( cd usr/include ; rm -rf png.h )
( cd usr/include ; ln -sf libpng10/png.h png.h )
( cd usr/include ; rm -rf pngconf.h )
( cd usr/include ; ln -sf libpng10/pngconf.h pngconf.h )
( cd usr/include ; rm -rf libpng )
( cd usr/include ; ln -sf libpng10 libpng )
( cd usr/bin ; rm -rf libpng-config )
( cd usr/bin ; ln -sf libpng10-config libpng-config )
( cd usr/lib ; rm -rf libpng.so.0 )
( cd usr/lib ; ln -sf libpng.so.2 libpng.so.0 )
( cd usr/lib ; rm -rf libpng10.so )
( cd usr/lib ; ln -sf libpng10.so.0 libpng10.so )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.40 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.40 )
( cd usr/lib ; rm -rf libpng.so.3.1.2.35 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.35 )
( cd usr/lib ; rm -rf libpng.a )
( cd usr/lib ; ln -sf libpng10.a libpng.a )
( cd usr/lib ; rm -rf libpng.so )
( cd usr/lib ; ln -sf libpng10.so libpng.so )
( cd usr/lib ; rm -rf libpng.so.1 )
( cd usr/lib ; ln -sf libpng.so.2 libpng.so.1 )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.25 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.25 )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.2 libpng.so.3 )
( cd usr/lib ; rm -rf libpng12.so )
( cd usr/lib ; ln -sf libpng10.so libpng12.so )
( cd usr/lib ; rm -rf libpng.so.3.1.2.38 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.38 )
( cd usr/lib ; rm -rf libpng10.so.0 )
( cd usr/lib ; ln -sf libpng10.so.0.54.0 libpng10.so.0 )
( cd usr/lib/pkgconfig ; rm -rf libpng.pc )
( cd usr/lib/pkgconfig ; ln -sf libpng10.pc libpng.pc )
( cd usr/lib ; rm -rf libpng12.a )
( cd usr/lib ; ln -sf libpng10.a libpng12.a )
( cd usr/lib ; rm -rf libpng.so.3.1.2.25 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.25 )
( cd usr/lib ; rm -rf libpng.la )
( cd usr/lib ; ln -sf libpng10.la libpng.la )
( cd usr/lib ; rm -rf libpng.so.2 )
( cd usr/lib ; ln -sf libpng.so.2.54.0 libpng.so.2 )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.35 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.35 )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so libpng12.so.0 )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.18 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.18 )
( cd usr/lib ; rm -rf libpng.so.3.1.2.40 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.40 )
( cd usr/lib ; rm -rf libpng12.so.0.1.2.38 )
( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so.0.1.2.38 )
( cd usr/lib ; rm -rf libpng.so.3.1.2.18 )
( cd usr/lib ; ln -sf libpng.so.3 libpng.so.3.1.2.18 )
( cd usr/lib ; rm -rf libpng.so.2.1.0.50 )
( cd usr/lib ; ln -sf libpng.so.2 libpng.so.2.1.0.50 )
( cd usr/lib ; rm -rf libpng10.so.0.1.0.50 )
( cd usr/lib ; ln -sf libpng10.so.0 libpng10.so.0.1.0.50 )
